@@ -77,7 +77,7 @@ unsigned time_lw_H()
 	} else {
 		cout << " failed ";
 	}
-	cout << int(1000*(time/count))*0.001 << 's' << endl;
+	cout << time/count << 's' << endl;
 
 	return result;
 }
