@@ -79,7 +79,7 @@ unsigned time_lw_Q()
 		} else {
 			cout << " failed ";
 		}
-		cout << int(1000*(time/count))*0.001 << 's' << endl;
+		cout << time/count << 's' << endl;
 	} else {
 		cout << " disabled" << endl;
 		clog << "(no output)" << endl;
