@@ -45,7 +45,7 @@ GINAC_IMPLEMENT_REGISTERED_CLASS_OPT(symbol, basic,
 // symbol
 
 symbol::symbol()
- : inherited(TINFO_symbol), asexinfop(new assigned_ex_info), serial(next_serial++), name(autoname_prefix() + ToString(serial)), TeX_name(name), ret_type(return_types::commutative), ret_type_tinfo(TINFO_symbol), domain(domain::complex)
+ : inherited(&symbol::tinfo_static), asexinfop(new assigned_ex_info), serial(next_serial++), name(autoname_prefix() + ToString(serial)), TeX_name(name), ret_type(return_types::commutative), ret_type_tinfo(&symbol::tinfo_static), domain(domain::complex)
 {
 	setflag(status_flags::evaluated | status_flags::expanded);
 }
@@ -57,6 +57,13 @@ realsymbol::realsymbol()
 	domain = domain::real;
 }
 
+// possymbol
+
+possymbol::possymbol()
+{
+	domain = domain::positive;
+}
+
 //////////
 // other constructors
 //////////
@@ -66,25 +73,25 @@ realsymbol::realsymbol()
 // symbol
 
 symbol::symbol(const std::string & initname, unsigned domain)
- : inherited(TINFO_symbol), asexinfop(new assigned_ex_info), serial(next_serial++), name(initname), TeX_name(default_TeX_name()), ret_type(return_types::commutative), ret_type_tinfo(TINFO_symbol), domain(domain)
+ : inherited(&symbol::tinfo_static), asexinfop(new assigned_ex_info), serial(next_serial++), name(initname), TeX_name(default_TeX_name()), ret_type(return_types::commutative), ret_type_tinfo(&symbol::tinfo_static), domain(domain)
+{
+	setflag(status_flags::evaluated | status_flags::expanded);
+}
+
+symbol::symbol(const std::string & initname, unsigned rt, tinfo_t rtt, unsigned domain)
+ : inherited(&symbol::tinfo_static), asexinfop(new assigned_ex_info), serial(next_serial++), name(initname), TeX_name(default_TeX_name()), ret_type(rt), ret_type_tinfo(rtt), domain(domain)
 {
 	setflag(status_flags::evaluated | status_flags::expanded);
 }
 
 symbol::symbol(const std::string & initname, const std::string & texname, unsigned domain)
- : inherited(TINFO_symbol), asexinfop(new assigned_ex_info), serial(next_serial++), name(initname), TeX_name(texname), ret_type(return_types::commutative), ret_type_tinfo(TINFO_symbol), domain(domain)
+ : inherited(&symbol::tinfo_static), asexinfop(new assigned_ex_info), serial(next_serial++), name(initname), TeX_name(texname), ret_type(return_types::commutative), ret_type_tinfo(&symbol::tinfo_static), domain(domain)
 {
 	setflag(status_flags::evaluated | status_flags::expanded);
 }
 
-symbol::symbol(const std::string & initname, unsigned rt, unsigned rtt, unsigned domain)
- : inherited(TINFO_symbol), asexinfop(new assigned_ex_info), serial(next_serial++), name(initname), TeX_name(default_TeX_name()), ret_type(rt), ret_type_tinfo(rtt), domain(domain)
-{
-	setflag(status_flags::evaluated | status_flags::expanded);
-}
-
-symbol::symbol(const std::string & initname, const std::string & texname, unsigned rt, unsigned rtt, unsigned domain)
- : inherited(TINFO_symbol), asexinfop(new assigned_ex_info), serial(next_serial++), name(initname), TeX_name(texname), ret_type(rt), ret_type_tinfo(rtt), domain(domain)
+symbol::symbol(const std::string & initname, const std::string & texname, unsigned rt, tinfo_t rtt, unsigned domain)
+ : inherited(&symbol::tinfo_static), asexinfop(new assigned_ex_info), serial(next_serial++), name(initname), TeX_name(texname), ret_type(rt), ret_type_tinfo(rtt), domain(domain)
 {
 	setflag(status_flags::evaluated | status_flags::expanded);
 }
@@ -97,10 +104,24 @@ realsymbol::realsymbol(const std::string & initname, unsigned domain)
 realsymbol::realsymbol(const std::string & initname, const std::string & texname, unsigned domain)
  : symbol(initname, texname, domain) { }
 
-realsymbol::realsymbol(const std::string & initname, unsigned rt, unsigned rtt, unsigned domain)
+realsymbol::realsymbol(const std::string & initname, unsigned rt, tinfo_t rtt, unsigned domain)
  : symbol(initname, rt, rtt, domain) { }
 
-realsymbol::realsymbol(const std::string & initname, const std::string & texname, unsigned rt, unsigned rtt, unsigned domain)
+realsymbol::realsymbol(const std::string & initname, const std::string & texname, unsigned rt, tinfo_t rtt, unsigned domain)
+ : symbol(initname, texname, rt, rtt, domain) { }
+
+// possymbol
+	
+possymbol::possymbol(const std::string & initname, unsigned domain)
+ : symbol(initname, domain) { }
+
+possymbol::possymbol(const std::string & initname, const std::string & texname, unsigned domain)
+ : symbol(initname, texname, domain) { }
+
+possymbol::possymbol(const std::string & initname, unsigned rt, tinfo_t rtt, unsigned domain)
+ : symbol(initname, rt, rtt, domain) { }
+
+possymbol::possymbol(const std::string & initname, const std::string & texname, unsigned rt, tinfo_t rtt, unsigned domain)
  : symbol(initname, texname, rt, rtt, domain) { }
 
 //////////
@@ -119,8 +140,6 @@ symbol::symbol(const archive_node &n, lst &sym_lst)
 		domain = domain::complex;
 	if (!n.find_unsigned("return_type", ret_type))
 		ret_type = return_types::commutative;
-	if (!n.find_unsigned("return_type_tinfo", ret_type_tinfo))
-		ret_type_tinfo = TINFO_symbol;
 	setflag(status_flags::evaluated | status_flags::expanded);
 }
 
@@ -151,8 +170,6 @@ void symbol::archive(archive_node &n) const
 		n.add_unsigned("domain", domain);
 	if (ret_type != return_types::commutative)
 		n.add_unsigned("return_type", ret_type);
-	if (ret_type_tinfo != TINFO_symbol)
-		n.add_unsigned("return_type_tinfo", ret_type_tinfo);
 }
 
 //////////
@@ -190,19 +207,25 @@ void symbol::do_print_python_repr(const print_python_repr & c, unsigned level) c
 
 bool symbol::info(unsigned inf) const
 {
-	if (inf == info_flags::symbol)
-		return true;
-	if (inf == info_flags::polynomial ||
-	    inf == info_flags::integer_polynomial ||
-	    inf == info_flags::cinteger_polynomial ||
-	    inf == info_flags::rational_polynomial ||
-	    inf == info_flags::crational_polynomial ||
-	    inf == info_flags::rational_function)
-		return true;
-	if (inf == info_flags::real)
-		return domain == domain::real;
-	else
-		return inherited::info(inf);
+	switch (inf) {
+		case info_flags::symbol:
+		case info_flags::polynomial:
+		case info_flags::integer_polynomial: 
+		case info_flags::cinteger_polynomial: 
+		case info_flags::rational_polynomial: 
+		case info_flags::crational_polynomial: 
+		case info_flags::rational_function: 
+		case info_flags::expanded:
+			return true;
+		case info_flags::real:
+			return domain == domain::real || domain == domain::positive;
+		case info_flags::positive:
+		case info_flags::nonnegative:
+			return domain == domain::positive;
+		case info_flags::has_indices:
+			return false;
+	}
+	return inherited::info(inf);
 }
 
 ex symbol::eval(int level) const
@@ -224,12 +247,31 @@ ex symbol::eval(int level) const
 ex symbol::conjugate() const
 {
 	if (this->domain == domain::complex) {
-		return GiNaC::conjugate_function(*this).hold();
+		return conjugate_function(*this).hold();
 	} else {
 		return *this;
 	}
 }
 
+ex symbol::real_part() const
+{
+	if (domain==domain::real || domain==domain::positive)
+		return *this;
+	return real_part_function(*this).hold();
+}
+
+ex symbol::imag_part() const
+{
+	if (domain==domain::real || domain==domain::positive)
+		return 0;
+	return imag_part_function(*this).hold();
+}
+
+bool symbol::is_polynomial(const ex & var) const
+{
+	return true;
+}
+
 // protected
 
 /** Implementation of ex::diff() for single differentiation of a symbol.
@@ -261,7 +303,7 @@ bool symbol::is_equal_same_type(const basic & other) const
 
 unsigned symbol::calchash() const
 {
-	hashvalue = golden_ratio_hash(tinfo() ^ serial);
+	hashvalue = golden_ratio_hash((p_int)tinfo() ^ serial);
 	setflag(status_flags::hash_calculated);
 	return hashvalue;
 }
